#!/usr/bin/env python

import sys
import os
import urllib2
import json
sys.path.append(os.getcwd() + '/../../comm/')
import gzip
import StringIO
import constant
from plugin_base import BaseSender
import cutils

class EventSender(BaseSender):
    def init(self):
        self.url = self.get_config('event_url')
        self.timeout = float(self.get_config('event_timeout'))/1000
        self.is_compress = int(self.get_config('is_compress'))

    def send_data(self, json_data):
        if cutils.is_minios():
            return
        try:
            if not cutils.check_net(self.url, self.timeout):
                self.url = self.get_config('event_url')

            req = urllib2.Request(self.url)
            req.add_header('Content-Type','application/json')
            timeout = self.timeout
            data = json.dumps(json_data)
            if self.is_compress == 1:
                try:
                    in_data = data
                    out = StringIO.StringIO()
                    f = gzip.GzipFile(fileobj=out, mode="wb")
                    f.write(in_data)
                    f.close()
                    data = out.getvalue()
                    req.add_header('Content-Encoding', 'gzip')
                    req.add_header('Content-Length', len(data))
                    self.logger().info("gzip compress before %d, after %d", len(in_data), len(data))
                except Exception,e:
                    self.logger().error("compress data error, error: %s, original data: %s", str(e), str(in_data))
            http_ret = urllib2.urlopen(req, data, timeout)
            response = http_ret.read()
            try:
                json_resp = json.loads(response)
                retcode = int(json_resp["returnCode"])
                if retcode != 0:
                    self.logger().error("event send error, retcode : %d, msg : %s, data : %s" % (retcode, json_resp["msg"], data))
                else:
                    self.logger().info("event send succ, data : %s" % str(data))
            except ValueError,e:
                self.logger().error("event send error, got a invalid json response : %s" % response)
        except urllib2.URLError,e:
            self.logger().error("send data error , error :%s, data : %s", str(e), data)


def main():
    sender = EventSender()
    data = { 'namespace':'qce/cvm/', 'name':'test', 'dimension':{ 'a':'1', 'b':'2' }, 'value':1.2 }
    sender.init()
    sender.send_data(data)

if __name__ == '__main__':
    main()
